package com.lantone.qc.pub.model;

import com.lantone.qc.pub.model.doc.BeHospitalizedDoc;
import com.lantone.qc.pub.model.doc.ClinicalBloodDoc;
import com.lantone.qc.pub.model.doc.ConsultationDoc;
import com.lantone.qc.pub.model.doc.DeathCaseDiscussDoc;
import com.lantone.qc.pub.model.doc.DeathRecordDoc;
import com.lantone.qc.pub.model.doc.DifficultCaseDiscussDoc;
import com.lantone.qc.pub.model.doc.DutyShiftSystemDoc;
import com.lantone.qc.pub.model.doc.FirstCourseRecordDoc;
import com.lantone.qc.pub.model.doc.FirstPageRecordDoc;
import com.lantone.qc.pub.model.doc.LeaveHospitalDoc;
import com.lantone.qc.pub.model.doc.NursingSystemDoc;
import com.lantone.qc.pub.model.doc.OperationDiscussionDoc;
import com.lantone.qc.pub.model.doc.PreoperativeDiscussionDoc;
import com.lantone.qc.pub.model.doc.RescueDoc;
import com.lantone.qc.pub.model.doc.ThreeLevelWardDoc;
import lombok.Getter;
import lombok.Setter;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @ClassName : InputInfo
 * @Description : 医院质控病历录入对象
 * @Author : 楼辉荣
 * @Date: 2020-03-04 15:39
 */
@Getter
@Setter
public class InputInfo {

    /**
     * 将要执行的规则，precond--规则执行前置条件
     * {"BEH0001":{"precond":"BEH0002,BEH0003,BEH0004"}}
     */
    private Map<String, Map<String, String>> inputCatalogueMap = new HashMap<>();
    //入院记录
    private BeHospitalizedDoc beHospitalizedDoc;
    //输血/血制品病程记录
    private List<ClinicalBloodDoc> clinicalBloodDocs = new ArrayList<>();
    //会诊记录
    private List<ConsultationDoc> consultationDocs = new ArrayList<>();
    //死亡病例讨论记录
    private DeathCaseDiscussDoc deathCaseDiscussDoc;
    //死亡记录
    private DeathRecordDoc deathRecordDoc;
    //疑难病例讨论记录
    private List<DifficultCaseDiscussDoc> difficultCaseDiscussDocs = new ArrayList<>();
    //值班交接制度
    private List<DutyShiftSystemDoc> dutyShiftSystemDocs = new ArrayList<>();
    //首次病程录
    private FirstCourseRecordDoc firstCourseRecordDoc;
    //病案首页
    private FirstPageRecordDoc firstPageRecordDoc;
    //出院小结
    private LeaveHospitalDoc leaveHospitalDoc;
    //分级护理制度
    private NursingSystemDoc nursingSystemDoc;
    //术后首次病程及谈话记录
    private List<OperationDiscussionDoc> operationDiscussionDocs = new ArrayList<>();
    //术前讨论、术前小结
    private List<PreoperativeDiscussionDoc> preoperativeDiscussionDocs = new ArrayList<>();
    //抢救记录
    private List<RescueDoc> rescueDocs = new ArrayList<>();
    //查房记录
    private List<ThreeLevelWardDoc> threeLevelWardDocs = new ArrayList<>();

    //新增记录
    public <T> void addDoc(List<T> list, T obj) {
        list.add(obj);
    }
}